@@ -74,7 +74,6 @@ OC.L10N.register(
     "Confirmed" : "Confirmate",
     "Hidden" : "Occultate",
     "can edit" : "pote modificar",
-    "Show week numbers" : "Monstrar le numero del septimanas",
-    "Keyboard shortcuts" : "Combinationes de claves"
+    "Show week numbers" : "Monstrar le numero del septimanas"
 },
 "nplurals=2; plural=(n != 1);");
