@@ -449,7 +449,6 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
     "Successfully appended link to talk room to description." : "Pokalbių kambario nuoroda sėkmingai pridėta į aprašą.",
     "Error creating Talk room" : "Klaida sukuriant pokalbių kambarį",
-    "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose.",
-    "Keyboard shortcuts" : "Spartieji klavišai"
+    "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
