@@ -188,15 +188,11 @@ OC.L10N.register(
     "At event start" : "Ved hendelsens start",
     "No reminder" : "Ingen påminnelse",
     "Failed to save default calendar" : "Lagring av standard kalender feilet",
-    "CalDAV link copied to clipboard." : "CalDAV-lenke kopiert til utklippstavlen.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
     "General" : "Generell",
-    "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
     "Appearance" : "Utseende",
     "Editing" : "Rediger",
-    "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
     "Default reminder" : "Standardpåminnelse",
-    "Keyboard shortcuts" : "Tastatursnarveier",
+    "Files" : "Filer",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutt","{duration} minutter"],
     "0 minutes" : "0 minutter",
     "_{duration} hour_::_{duration} hours_" : ["{duration} time","{duration} timer"],
@@ -318,12 +314,7 @@ OC.L10N.register(
     "Decline" : "Avslå",
     "Tentative" : "Foreløpig",
     "No attendees yet" : "Ingen deltakere enda",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitert, {confirmedCount} bekreftet",
-    "Successfully appended link to talk room to location." : "Lenke til talk-rom til plassering er lagt til.",
-    "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
-    "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
     "Attendees" : "Deltakere",
-    "_%n more guest_::_%n more guests_" : ["%n gjest til","%n flere gjester"],
     "Remove group" : "Fjern gruppe",
     "Remove attendee" : "Fjern deltaker",
     "Request reply" : "Be om svar",
@@ -550,6 +541,8 @@ OC.L10N.register(
     "Default attachments location" : "Standard plassering for vedlegg",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "Shortcut overview" : "Oversikt over snarveier",
+    "CalDAV link copied to clipboard." : "CalDAV-lenke kopiert til utklippstavlen.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
     "Enable birthday calendar" : "Aktiver fødselsdagkalender",
     "Show tasks in calendar" : "Vis oppgaver i kalender",
     "Enable simplified editor" : "Aktiver forenklet redigering",
@@ -557,9 +550,16 @@ OC.L10N.register(
     "Show weekends" : "Vis helger",
     "Show week numbers" : "Vis ukenummer",
     "Time increments" : "Tidsøkninger",
+    "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
     "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
+    "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
     "Personal availability settings" : "Personlig ledighets-innstillinger",
     "Show keyboard shortcuts" : "Vis tastatursnarveier",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitert, {confirmedCount} bekreftet",
+    "Successfully appended link to talk room to location." : "Lenke til talk-rom til plassering er lagt til.",
+    "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
+    "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
+    "_%n more guest_::_%n more guests_" : ["%n gjest til","%n flere gjester"],
     "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere"
 },
 "nplurals=2; plural=(n != 1);");
