@@ -94,6 +94,7 @@ OC.L10N.register(
     "Delete permanently" : "Eliminar permanentemente",
     "Could not update calendar order." : "Não foi possível atualizar a ordenação do calendário.",
     "Deck" : "Quadro",
+    "Internal link" : "Ligação interna",
     "Copy internal link" : "Copiar ligação interna",
     "An error occurred, unable to publish calendar." : "Ocorreu um erro, não foi possível publicar o calendário.",
     "An error occurred, unable to send email." : "Ocorreu um erro, não foi possível enviar o email.",
@@ -150,6 +151,7 @@ OC.L10N.register(
     "Calendar settings" : "Configurações do calendário",
     "No reminder" : "Nenhum lembrete",
     "General" : "Geral",
+    "Appearance" : "Aspeto",
     "Editing" : "A editar",
     "Default reminder" : "Lembrete padrão",
     "Files" : "Ficheiros",
@@ -311,7 +313,6 @@ OC.L10N.register(
     "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
     "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
     "Personal availability settings" : "Configurações de disponibilidade pessoal",
-    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
-    "Keyboard shortcuts" : "Atalhos de teclado"
+    "Show keyboard shortcuts" : "Mostrar atalhos de teclado"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
